"use strict";
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.indent = exports.log = exports.logInfo = exports.logError = void 0;
var chalk_1 = __importDefault(require("chalk"));
var prettyjson_1 = __importDefault(require("prettyjson"));
/**
 * Log an error message.
 *
 * @param args -
 *   arguments to format
 */
function logError() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    process.stderr.write(prettify.apply(void 0, __spreadArray([chalk_1.default.bgRed.white(' ERROR ')], args, false)));
}
exports.logError = logError;
/**
 * Log an info message.
 *
 * @param args -
 *   arguments to format
 */
function logInfo() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    process.stdout.write(prettify.apply(void 0, __spreadArray([chalk_1.default.bgWhite.black(' INFO ')], args, false)));
}
exports.logInfo = logInfo;
/**
 * Log a plain message.
 *
 * @param args -
 *   arguments to format
 */
function log() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    process.stdout.write(prettify.apply(void 0, args));
}
exports.log = log;
/**
 * Indent a log message with a certain amount of space.
 *
 * @param spaces -
 *   spaces to indent with
 * @param args -
 *   arguments to format
 * @returns
 *   formatted and indented string
 */
function indent(spaces) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    var text = prettify.apply(void 0, args);
    if (spaces <= 0)
        return text;
    var spacing = ' '.repeat(spaces);
    return text.split('\n')
        .map(function (line) { return line.length === 0 ? line : spacing + line; })
        .join('\n');
}
exports.indent = indent;
/**
 * Prettify a set of arguments for logging.
 *
 * @param args -
 *   arguments to format
 * @returns
 *   formatted string
 */
function prettify() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    var result = '';
    for (var _a = 0, args_1 = args; _a < args_1.length; _a++) {
        var arg = args_1[_a];
        if (result.length > 0)
            result += ' ';
        if (typeof arg === 'string') {
            result += arg;
        }
        else if (typeof arg === 'undefined') {
            result += chalk_1.default.gray('undefined');
        }
        else {
            result += prettyjson_1.default.render(arg);
        }
    }
    return result + '\n';
}
//# sourceMappingURL=log.js.map