"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createNetwork = void 0;
var ataraxia_1 = require("ataraxia");
var ataraxia_hyperswarm_1 = require("ataraxia-hyperswarm");
var ataraxia_local_1 = require("ataraxia-local");
var ataraxia_tcp_1 = require("ataraxia-tcp");
var log_1 = require("../log");
var resolveAuth_1 = require("./resolveAuth");
var stopNetwork_1 = require("./stopNetwork");
/**
 * Create a network based on command line arguments.
 *
 * @param args -
 *   parsed command line arguments
 * @returns
 *   network
 */
function createNetwork(args) {
    var _a;
    var auth = (0, resolveAuth_1.resolveAuth)(args);
    var net = new ataraxia_1.Network({
        name: (_a = args.network) !== null && _a !== void 0 ? _a : 'ataraxia-cli',
        endpoint: true,
    });
    if (args.network) {
        net.addTransport(new ataraxia_local_1.MachineLocalTransport());
        net.addTransport(new ataraxia_tcp_1.TCPTransport({
            discovery: new ataraxia_tcp_1.TCPPeerMDNSDiscovery(),
            authentication: auth
        }));
    }
    if (args.hyperswarm) {
        net.addTransport(new ataraxia_hyperswarm_1.HyperswarmTransport({
            topic: args.hyperswarm,
            authentication: auth
        }));
    }
    // Add a hook that stops the process when the network stops
    process.on('SIGINT', function () {
        (0, log_1.logInfo)('Shutting down network');
        (0, stopNetwork_1.stopNetwork)(net);
    });
    return net;
}
exports.createNetwork = createNetwork;
//# sourceMappingURL=createNetwork.js.map